@@ -5,18 +5,16 @@ from .eth_module import (  # noqa: F401
 from .go_ethereum_admin_module import (  # noqa: F401
     GoEthereumAdminModuleTest,
 )
+from .go_ethereum_txpool_module import (  # noqa: F401
+    GoEthereumAsyncTxPoolModuleTest,
+    GoEthereumTxPoolModuleTest
+)
 from .net_module import (  # noqa: F401
     AsyncNetModuleTest,
     NetModuleTest,
 )
-from .parity_module import (  # noqa: F401
-    ParityModuleTest,
-    ParitySetModuleTest,
-    ParityTraceModuleTest,
-)
-from .personal_module import (  # noqa: F401
+from .go_ethereum_personal_module import (  # noqa: F401
     GoEthereumPersonalModuleTest,
-    ParityPersonalModuleTest,
 )
 from .version_module import (  # noqa: F401
     VersionModuleTest,
